##############################################################################
#
# Copyright (c) 2005 Zope Foundation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
#
##############################################################################


def initialize(context):
    """Intializer called when used as a Zope 2 product."""
    import testrecorder
    context.registerClass(
        testrecorder.TestRecorder,
        permission='View',
        constructors=(testrecorder.addform,
                      testrecorder.add),
        icon='www/recorder.gif',
    )





##############################################################################
#
# Copyright (c) 2010 Zope Foundation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
#
##############################################################################
import unittest

class TestRecorderTests(unittest.TestCase):

    def _getTargetClass(self):
        from zope.testrecorder.testrecorder import TestRecorder
        return TestRecorder

    def _makeOne(self, id='test', title=''):
        return self._getTargetClass()(id, title)

    def test_has_resource_html(self):
        from Products.PageTemplates.PageTemplateFile import PageTemplateFile
        recorder = self._makeOne()
        index = getattr(recorder, 'index.html', None)
        self.failUnless(isinstance(index, PageTemplateFile))

    def test_index_html_has_docstring(self):
        klass = self._getTargetClass()
        index_html = klass.index_html.im_func
        self.failUnless(index_html.__doc__)

    def test_index_html_redirects(self):
        from OFS.Folder import Folder
        root = Folder()
        recorder = self._makeOne().__of__(root)
        response = DummyResponse()
        request = {'RESPONSE': response}
        recorder.index_html(request)
        self.assertEqual(response._redirected,
                         'test/index.html')

class DummyResponse:

    _redirected = None

    def redirect(self, url):
        self._redirected = url


def test_suite():
    return unittest.TestSuite((
        unittest.makeSuite(TestRecorderTests),
    ))



##############################################################################
#
# Copyright (c) 2005 Zope Foundation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
#
##############################################################################

import os

from App.class_init import InitializeClass
from AccessControl import ClassSecurityInfo
from OFS.SimpleItem import SimpleItem
from Products.PageTemplates.PageTemplateFile import PageTemplateFile

_www = os.path.join(os.path.dirname(__file__), 'www')
html = os.path.join(os.path.dirname(__file__), 'html')
view = 'View'


class TestRecorder(SimpleItem):
    """
    Test recorder object for Zope 2. This primarily exists to provide for
    traversal to the .js and .html files that make up the test recorder.
    """
    
    security = ClassSecurityInfo()
    meta_type = 'Test Recorder'

    manage_options = (
        {'label':'Info', 'action': 'manage_main'},
        ) + SimpleItem.manage_options

    security.declareProtected(view, 'manage_main')
    manage_main = PageTemplateFile('main.pt', _www)

    def __init__(self, id, title=''):
        self.id = id
        self.title = title

    security.declareProtected(view, 'index_html')
    def index_html(self, REQUEST):
        """ Redirect to resource page.
        """
        REQUEST['RESPONSE'].redirect(self.absolute_url()+'/index.html')

    dict = locals()
    for name in os.listdir(html):
        if name.endswith('.html') or name.endswith('.js'):
            security.declareProtected(view, name)
            dict[name] = PageTemplateFile(name, html)


InitializeClass(TestRecorder)


addform = PageTemplateFile('addform.pt', _www)

def add(self, id, title='', RESPONSE=None):
    """add method"""
    obj = TestRecorder(id, title)
    self._setObject(id, obj)
    if RESPONSE is not None:
        RESPONSE.redirect(self.absolute_url()+'/manage_main')



##############################################################################
#
# Copyright (c) 2006-2007 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
# This package is developed by the Zope Toolkit project, documented here:
# http://docs.zope.org/zopetoolkit
# When developing and releasing this package, please follow the documented
# Zope Toolkit policies as described by this documentation.
##############################################################################
"""Setup for zope.testrecorder package
"""
import os
try:
    from setuptools import setup
except ImportError, e:
    from distutils.core import setup

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

setup(name='zope.testrecorder',
      version='0.4',
      author='Zope Foundation and Contributors',
      author_email='zope-dev@zope.org',
      description='Test recorder for functional tests',
      long_description=(
          read('README.txt')
          + '\n\n' +
          read('CHANGES.txt')
          ),
      keywords='web testing',
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'License :: OSI Approved :: Zope Public License',
          'Operating System :: OS Independent',
          'Topic :: Internet :: WWW/HTTP :: Browsers',
          'Topic :: Software Development :: Testing',
          ],

      url='http://pypi.python.org/pypi/zope.testrecorder',
      license='ZPL 2.1',
      packages=['zope', 'zope.testrecorder'],
      package_dir = {'': 'src'},
      namespace_packages=['zope'],
      install_requires=[
        'setuptools',
      ],
      extras_require={
        'test': ['Zope2']
      },
      include_package_data = True,
      zip_safe = False,
)
